@@ -74,6 +74,7 @@ extern "C"
 #include "reset_group.h"
 #include "exit_failure.h"
 #include "multiple_option_token_functions.h"
+#include "update_given.h"
 
 #ifndef HAVE_STRDUP
 extern "C" char *strdup (const char *s) ;
@@ -1096,6 +1097,30 @@ CmdlineParserCreator::generate_multiple_fill_array(ostream &stream, unsigned int
     }
 }
 
+void
+CmdlineParserCreator::generate_update_multiple_given(ostream &stream, unsigned int indent)
+{
+  if (! has_multiple_options())
+    return;
+
+  string indent_str (indent, ' ');
+
+  stream << endl;
+  stream << indent_str;
+
+  update_given_gen_class update_given_gen;
+  struct gengetopt_option * opt;
+
+  foropt
+    {
+      if (opt->multiple)
+	{
+          update_given_gen.set_option_var_name (opt->var_arg);
+          update_given_gen.generate_update_given (stream, indent);
+        }
+    }
+}
+
 void
 CmdlineParserCreator::generate_clear_arg(ostream &stream, unsigned int indent)
 {
